@@ -4,7 +4,7 @@ use Moo;
 use Carp qw(croak);
 use namespace::clean;
 
-our $VERSION = '2.0.1';
+our $VERSION = '2.0.2';
 
 has position => (
     is => 'rw',
@@ -101,7 +101,7 @@ __END__
 
 =head1 NAME
 
-L<MARC::Spec::Indicator|MARC::Spec::Indicator> - indicator specification
+MARC::Spec::Indicator - indicator specification
 
 =head1 SYNOPSIS
 
@@ -113,7 +113,7 @@ L<MARC::Spec::Indicator|MARC::Spec::Indicator> - indicator specification
 
 =head1 DESCRIPTION
 
-L<MARC::Spec::Indicator|MARC::Spec::Indicator> is the indicator specification of a L<MARC::Spec|MARC::Spec>.
+MARC::Spec::Indicator is the indicator specification of a L<MARC::Spec|MARC::Spec>.
 
 See L<MARCspec - A common MARC record path language|http://marcspec.github.io/MARCspec/> for further 
 details on the syntax.
@@ -194,12 +194,22 @@ Please report any bugs to L<https://github.com/MARCspec/MARC-Spec/issues|https:/
 
 =head1 SEE ALSO
 
-L<MARC::Spec|MARC::Spec>,
-L<MARC::Spec::Subfield|MARC::Spec::Subfield>,
-L<MARC::Spec::Field|MARC::Spec::Field>,
-L<MARC::Spec::Subspec|MARC::Spec::Subspec>,
-L<MARC::Spec::Structure|MARC::Spec::Structure>,
-L<MARC::Spec::Comparisonstring|MARC::Spec::Comparisonstring>,
-L<MARC::Spec::Parser|MARC::Spec::Parser>
+=over
+
+=item * L<MARC::Spec|MARC::Spec>
+
+=item * L<MARC::Spec::Field|MARC::Spec::Field>
+
+=item * L<MARC::Spec::Subfield|MARC::Spec::Subfield>
+
+=item * L<MARC::Spec::Subspec|MARC::Spec::Subspec>
+
+=item * L<MARC::Spec::Structure|MARC::Spec::Structure>
+
+=item * L<MARC::Spec::Comparisonstring|MARC::Spec::Comparisonstring>
+
+=item * L<MARC::Spec::Parser|MARC::Spec::Parser>
+
+=back
 
 =cut
