@@ -3,7 +3,7 @@ package MARC::Spec::Subspec;
 use Moo;
 use namespace::clean;
 
-our $VERSION = '2.0.1';
+our $VERSION = '2.0.2';
 
 has left => (
     is => 'rw',
@@ -40,7 +40,7 @@ __END__
 
 =head1 NAME
 
-L<MARC::Spec::Subspec|MARC::Spec::Subspec> - subspec specification
+MARC::Spec::Subspec - subspec specification
 
 =head1 SYNOPSIS
 
@@ -64,7 +64,7 @@ L<MARC::Spec::Subspec|MARC::Spec::Subspec> - subspec specification
 
 =head1 DESCRIPTION
 
-L<MARC::Spec::Subspec|MARC::Spec::Subspec> is the subspec specification of a L<MARC::Spec|MARC::Spec>.
+MARC::Spec::Subspec is the subspec specification of a L<MARC::Spec|MARC::Spec>.
 
 See L<MARCspec - A common MARC record path language|http://marcspec.github.io/MARCspec/> for further 
 details on the syntax.
@@ -118,11 +118,21 @@ Please report any bugs to L<https://github.com/MARCspec/MARC-Spec/issues|https:/
 
 =head1 SEE ALSO
 
-L<MARC::Spec|MARC::Spec>,
-L<MARC::Spec::Field|MARC::Spec::Field>,
-L<MARC::Spec::Subfield|MARC::Spec::Subfield>,
-L<MARC::Spec::Structure|MARC::Spec::Structure>,
-L<MARC::Spec::Comparisonstring|MARC::Spec::Comparisonstring>,
-L<MARC::Spec::Parser|MARC::Spec::Parser>
+=over
 
+=item * L<MARC::Spec|MARC::Spec>
+
+=item * L<MARC::Spec::Field|MARC::Spec::Field>
+
+=item * L<MARC::Spec::Subfield|MARC::Spec::Subfield>
+
+=item * L<MARC::Spec::Indicator|MARC::Spec::Indicator>
+
+=item * L<MARC::Spec::Structure|MARC::Spec::Structure>
+
+=item * L<MARC::Spec::Comparisonstring|MARC::Spec::Comparisonstring>
+
+=item * L<MARC::Spec::Parser|MARC::Spec::Parser>
+
+=back
 =cut
